@@ -67,8 +67,7 @@ static gboolean output_received (GIOChannel *channel,
 
   while(length != 0)
     {
-      GIOStatus status;
-      status = g_io_channel_read_chars(channel, buffer, 1024, &length, &error);
+      g_io_channel_read_chars(channel, buffer, 1024, &length, &error);
       if(error)
         {
           g_warning("%s", error->message);
@@ -102,8 +101,7 @@ static gboolean input_received (GIOChannel *channel,
 
   while(length != 0)
     {
-      GIOStatus status;
-      status = g_io_channel_read_chars(channel, buffer, 1024, &length, &error);
+      g_io_channel_read_chars(channel, buffer, 1024, &length, &error);
       if(error)
         {
           g_warning("%s", error->message);
