@@ -20,7 +20,7 @@
 #ifndef __GKSU_PROCESS_ERROR_H__
 #define __GKSU_PROCESS_ERROR_H__ 1
 
-#include <glib/gerror.h>
+#include <glib.h>
 
 #define GKSU_PROCESS_ERROR g_quark_from_static_string("gksu-process-error")
 
@@ -30,4 +30,4 @@ typedef enum
     GKSU_PROCESS_ERROR_DBUS,
   } GksuProcessErrorEnum;
 
-#endif
\ No newline at end of file
+#endif
