@@ -25,7 +25,6 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#include <glib-object.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 #include <dbus/dbus.h>
@@ -126,6 +125,7 @@ static void output_available_cb(DBusGProxy *server, gint pid, gint fd, GksuProce
   GksuProcessPrivate *priv = GKSU_PROCESS_GET_PRIVATE(self);
   GError *error = NULL;
   gchar *data = NULL;
+  guint64 uint_length;
   gsize length;
 
   if(pid != priv->pid)
@@ -136,9 +136,11 @@ static void output_available_cb(DBusGProxy *server, gint pid, gint fd, GksuProce
                     G_TYPE_INT, fd,
                     G_TYPE_INVALID,
                     G_TYPE_STRING, &data,
-                    G_TYPE_UINT, &length,
+                    G_TYPE_UINT64, &uint_length,
                     G_TYPE_INVALID);
 
+  length = (gsize)uint_length;
+
   if(error)
     {
       g_warning("%s", error->message);
@@ -409,8 +411,7 @@ static gchar* read_all_from_channel(GIOChannel *channel, gsize *length)
 
   while(buffer_length != 0)
     {
-      GIOStatus status;
-      status = g_io_channel_read_chars(channel, buffer, 1024, &buffer_length, &error);
+      g_io_channel_read_chars(channel, buffer, 1024, &buffer_length, &error);
       if(error)
         {
           fprintf(stderr, "%s\n", error->message);
@@ -522,7 +523,7 @@ gksu_process_stdin_ready_to_send_cb(GIOChannel *channel, GIOCondition condition,
   dbus_g_proxy_call(priv->server, "WriteInput", &error,
                     G_TYPE_UINT, priv->cookie,
                     G_TYPE_STRING, data,
-                    G_TYPE_UINT, length,
+                    G_TYPE_UINT64, (guint64)length,
                     G_TYPE_INVALID,
                     G_TYPE_INVALID);
   g_free(data);
