@@ -20,7 +20,7 @@
 #ifndef __GKSU_ERROR_H__
 #define __GKSU_ERROR_H__ 1
 
-#include <glib/gerror.h>
+#include <glib.h>
 
 #define GKSU_ERROR g_quark_from_static_string("gksu-error")
 
