@@ -261,7 +261,7 @@ static void gksu_server_init(GksuServer *self)
 		      &dbus_error);
 
   /* PolicyKit setup */
-  priv->authority = polkit_authority_get();
+  priv->authority = polkit_authority_get_sync(NULL, NULL);
 
   /* Setup our main filter to handle the DBus messages */
   dbus_connection_add_filter(connection, gksu_server_handle_dbus_message,
